==> sam-1.0.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/sam/CfnLayerVersionProps.java <==
package software.amazon.awscdk.services.sam;

/**
 * Properties for defining a `AWS::Serverless::LayerVersion`.
 * 
 * @see https://github.com/awslabs/serverless-application-model/blob/master/versions/2016-10-31.md#awsserverlesslayerversion
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.0 (build a586a1a)", date = "2019-07-11T14:10:32.416Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnLayerVersionProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::Serverless::LayerVersion.CompatibleRuntimes`.
     * 
     * @see https://github.com/awslabs/serverless-application-model/blob/master/versions/2016-10-31.md#awsserverlesslayerversion
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.util.List<java.lang.String> getCompatibleRuntimes();
    /**
     * `AWS::Serverless::LayerVersion.ContentUri`.
     * 
     * @see https://github.com/awslabs/serverless-application-model/blob/master/versions/2016-10-31.md#awsserverlesslayerversion
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getContentUri();
    /**
     * `AWS::Serverless::LayerVersion.Description`.
     * 
     * @see https://github.com/awslabs/serverless-application-model/blob/master/versions/2016-10-31.md#awsserverlesslayerversion
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getDescription();
    /**
     * `AWS::Serverless::LayerVersion.LayerName`.
     * 
     * @see https://github.com/awslabs/serverless-application-model/blob/master/versions/2016-10-31.md#awsserverlesslayerversion
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getLayerName();
    /**
     * `AWS::Serverless::LayerVersion.LicenseInfo`.
     * 
     * @see https://github.com/awslabs/serverless-application-model/blob/master/versions/2016-10-31.md#awsserverlesslayerversion
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getLicenseInfo();
    /**
     * `AWS::Serverless::LayerVersion.RetentionPolicy`.
     * 
     * @see https://github.com/awslabs/serverless-application-model/blob/master/versions/2016-10-31.md#awsserverlesslayerversion
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getRetentionPolicy();

    /**
     * @return a {@link Builder} of {@link CfnLayerVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnLayerVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Builder {
        @javax.annotation.Nullable
        private java.util.List<java.lang.String> _compatibleRuntimes;
        @javax.annotation.Nullable
        private java.lang.String _contentUri;
        @javax.annotation.Nullable
        private java.lang.String _description;
        @javax.annotation.Nullable
        private java.lang.String _layerName;
        @javax.annotation.Nullable
        private java.lang.String _licenseInfo;
        @javax.annotation.Nullable
        private java.lang.String _retentionPolicy;

        /**
         * Sets the value of CompatibleRuntimes
         * @param value `AWS::Serverless::LayerVersion.CompatibleRuntimes`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withCompatibleRuntimes(@javax.annotation.Nullable final java.util.List<java.lang.String> value) {
            this._compatibleRuntimes = value;
            return this;
        }
        /**
         * Sets the value of ContentUri
         * @param value `AWS::Serverless::LayerVersion.ContentUri`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withContentUri(@javax.annotation.Nullable final java.lang.String value) {
            this._contentUri = value;
            return this;
        }
        /**
         * Sets the value of Description
         * @param value `AWS::Serverless::LayerVersion.Description`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withDescription(@javax.annotation.Nullable final java.lang.String value) {
            this._description = value;
            return this;
        }
        /**
         * Sets the value of LayerName
         * @param value `AWS::Serverless::LayerVersion.LayerName`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withLayerName(@javax.annotation.Nullable final java.lang.String value) {
            this._layerName = value;
            return this;
        }
        /**
         * Sets the value of LicenseInfo
         * @param value `AWS::Serverless::LayerVersion.LicenseInfo`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withLicenseInfo(@javax.annotation.Nullable final java.lang.String value) {
            this._licenseInfo = value;
            return this;
        }
        /**
         * Sets the value of RetentionPolicy
         * @param value `AWS::Serverless::LayerVersion.RetentionPolicy`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withRetentionPolicy(@javax.annotation.Nullable final java.lang.String value) {
            this._retentionPolicy = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnLayerVersionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public CfnLayerVersionProps build() {
            return new CfnLayerVersionProps() {
                @javax.annotation.Nullable
                private final java.util.List<java.lang.String> $compatibleRuntimes = _compatibleRuntimes;
                @javax.annotation.Nullable
                private final java.lang.String $contentUri = _contentUri;
                @javax.annotation.Nullable
                private final java.lang.String $description = _description;
                @javax.annotation.Nullable
                private final java.lang.String $layerName = _layerName;
                @javax.annotation.Nullable
                private final java.lang.String $licenseInfo = _licenseInfo;
                @javax.annotation.Nullable
                private final java.lang.String $retentionPolicy = _retentionPolicy;

                @Override
                public java.util.List<java.lang.String> getCompatibleRuntimes() {
                    return this.$compatibleRuntimes;
                }

                @Override
                public java.lang.String getContentUri() {
                    return this.$contentUri;
                }

                @Override
                public java.lang.String getDescription() {
                    return this.$description;
                }

                @Override
                public java.lang.String getLayerName() {
                    return this.$layerName;
                }

                @Override
                public java.lang.String getLicenseInfo() {
                    return this.$licenseInfo;
                }

                @Override
                public java.lang.String getRetentionPolicy() {
                    return this.$retentionPolicy;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    if (this.getCompatibleRuntimes() != null) {
                        obj.set("compatibleRuntimes", om.valueToTree(this.getCompatibleRuntimes()));
                    }
                    if (this.getContentUri() != null) {
                        obj.set("contentUri", om.valueToTree(this.getContentUri()));
                    }
                    if (this.getDescription() != null) {
                        obj.set("description", om.valueToTree(this.getDescription()));
                    }
                    if (this.getLayerName() != null) {
                        obj.set("layerName", om.valueToTree(this.getLayerName()));
                    }
                    if (this.getLicenseInfo() != null) {
                        obj.set("licenseInfo", om.valueToTree(this.getLicenseInfo()));
                    }
                    if (this.getRetentionPolicy() != null) {
                        obj.set("retentionPolicy", om.valueToTree(this.getRetentionPolicy()));
                    }
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.sam.CfnLayerVersionProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * `AWS::Serverless::LayerVersion.CompatibleRuntimes`.
         * 
         * @see https://github.com/awslabs/serverless-application-model/blob/master/versions/2016-10-31.md#awsserverlesslayerversion
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.util.List<java.lang.String> getCompatibleRuntimes() {
            return this.jsiiGet("compatibleRuntimes", java.util.List.class);
        }

        /**
         * `AWS::Serverless::LayerVersion.ContentUri`.
         * 
         * @see https://github.com/awslabs/serverless-application-model/blob/master/versions/2016-10-31.md#awsserverlesslayerversion
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.lang.String getContentUri() {
            return this.jsiiGet("contentUri", java.lang.String.class);
        }

        /**
         * `AWS::Serverless::LayerVersion.Description`.
         * 
         * @see https://github.com/awslabs/serverless-application-model/blob/master/versions/2016-10-31.md#awsserverlesslayerversion
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.lang.String getDescription() {
            return this.jsiiGet("description", java.lang.String.class);
        }

        /**
         * `AWS::Serverless::LayerVersion.LayerName`.
         * 
         * @see https://github.com/awslabs/serverless-application-model/blob/master/versions/2016-10-31.md#awsserverlesslayerversion
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.lang.String getLayerName() {
            return this.jsiiGet("layerName", java.lang.String.class);
        }

        /**
         * `AWS::Serverless::LayerVersion.LicenseInfo`.
         * 
         * @see https://github.com/awslabs/serverless-application-model/blob/master/versions/2016-10-31.md#awsserverlesslayerversion
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.lang.String getLicenseInfo() {
            return this.jsiiGet("licenseInfo", java.lang.String.class);
        }

        /**
         * `AWS::Serverless::LayerVersion.RetentionPolicy`.
         * 
         * @see https://github.com/awslabs/serverless-application-model/blob/master/versions/2016-10-31.md#awsserverlesslayerversion
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.lang.String getRetentionPolicy() {
            return this.jsiiGet("retentionPolicy", java.lang.String.class);
        }
    }
}

==> sam-1.1.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/sam/CfnLayerVersionProps.java <==
package software.amazon.awscdk.services.sam;

/**
 * Properties for defining a `AWS::Serverless::LayerVersion`.
 * 
 * @see https://github.com/awslabs/serverless-application-model/blob/master/versions/2016-10-31.md#awsserverlesslayerversion
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.2 (build e881f16)", date = "2019-07-19T19:03:57.092Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnLayerVersionProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::Serverless::LayerVersion.CompatibleRuntimes`.
     * 
     * @see https://github.com/awslabs/serverless-application-model/blob/master/versions/2016-10-31.md#awsserverlesslayerversion
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.util.List<java.lang.String> getCompatibleRuntimes();
    /**
     * `AWS::Serverless::LayerVersion.ContentUri`.
     * 
     * @see https://github.com/awslabs/serverless-application-model/blob/master/versions/2016-10-31.md#awsserverlesslayerversion
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getContentUri();
    /**
     * `AWS::Serverless::LayerVersion.Description`.
     * 
     * @see https://github.com/awslabs/serverless-application-model/blob/master/versions/2016-10-31.md#awsserverlesslayerversion
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getDescription();
    /**
     * `AWS::Serverless::LayerVersion.LayerName`.
     * 
     * @see https://github.com/awslabs/serverless-application-model/blob/master/versions/2016-10-31.md#awsserverlesslayerversion
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getLayerName();
    /**
     * `AWS::Serverless::LayerVersion.LicenseInfo`.
     * 
     * @see https://github.com/awslabs/serverless-application-model/blob/master/versions/2016-10-31.md#awsserverlesslayerversion
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getLicenseInfo();
    /**
     * `AWS::Serverless::LayerVersion.RetentionPolicy`.
     * 
     * @see https://github.com/awslabs/serverless-application-model/blob/master/versions/2016-10-31.md#awsserverlesslayerversion
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getRetentionPolicy();

    /**
     * @return a {@link Builder} of {@link CfnLayerVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnLayerVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Builder {
        @javax.annotation.Nullable
        private java.util.List<java.lang.String> _compatibleRuntimes;
        @javax.annotation.Nullable
        private java.lang.String _contentUri;
        @javax.annotation.Nullable
        private java.lang.String _description;
        @javax.annotation.Nullable
        private java.lang.String _layerName;
        @javax.annotation.Nullable
        private java.lang.String _licenseInfo;
        @javax.annotation.Nullable
        private java.lang.String _retentionPolicy;

        /**
         * Sets the value of CompatibleRuntimes
         * @param value `AWS::Serverless::LayerVersion.CompatibleRuntimes`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withCompatibleRuntimes(@javax.annotation.Nullable final java.util.List<java.lang.String> value) {
            this._compatibleRuntimes = value;
            return this;
        }
        /**
         * Sets the value of ContentUri
         * @param value `AWS::Serverless::LayerVersion.ContentUri`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withContentUri(@javax.annotation.Nullable final java.lang.String value) {
            this._contentUri = value;
            return this;
        }
        /**
         * Sets the value of Description
         * @param value `AWS::Serverless::LayerVersion.Description`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withDescription(@javax.annotation.Nullable final java.lang.String value) {
            this._description = value;
            return this;
        }
        /**
         * Sets the value of LayerName
         * @param value `AWS::Serverless::LayerVersion.LayerName`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withLayerName(@javax.annotation.Nullable final java.lang.String value) {
            this._layerName = value;
            return this;
        }
        /**
         * Sets the value of LicenseInfo
         * @param value `AWS::Serverless::LayerVersion.LicenseInfo`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withLicenseInfo(@javax.annotation.Nullable final java.lang.String value) {
            this._licenseInfo = value;
            return this;
        }
        /**
         * Sets the value of RetentionPolicy
         * @param value `AWS::Serverless::LayerVersion.RetentionPolicy`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withRetentionPolicy(@javax.annotation.Nullable final java.lang.String value) {
            this._retentionPolicy = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnLayerVersionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnLayerVersionProps build() {
            return new CfnLayerVersionProps() {
                @javax.annotation.Nullable
                private final java.util.List<java.lang.String> $compatibleRuntimes = _compatibleRuntimes;
                @javax.annotation.Nullable
                private final java.lang.String $contentUri = _contentUri;
                @javax.annotation.Nullable
                private final java.lang.String $description = _description;
                @javax.annotation.Nullable
                private final java.lang.String $layerName = _layerName;
                @javax.annotation.Nullable
                private final java.lang.String $licenseInfo = _licenseInfo;
                @javax.annotation.Nullable
                private final java.lang.String $retentionPolicy = _retentionPolicy;

                @Override
                public java.util.List<java.lang.String> getCompatibleRuntimes() {
                    return this.$compatibleRuntimes;
                }

                @Override
                public java.lang.String getContentUri() {
                    return this.$contentUri;
                }

                @Override
                public java.lang.String getDescription() {
                    return this.$description;
                }

                @Override
                public java.lang.String getLayerName() {
                    return this.$layerName;
                }

                @Override
                public java.lang.String getLicenseInfo() {
                    return this.$licenseInfo;
                }

                @Override
                public java.lang.String getRetentionPolicy() {
                    return this.$retentionPolicy;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    if (this.getCompatibleRuntimes() != null) {
                        obj.set("compatibleRuntimes", om.valueToTree(this.getCompatibleRuntimes()));
                    }
                    if (this.getContentUri() != null) {
                        obj.set("contentUri", om.valueToTree(this.getContentUri()));
                    }
                    if (this.getDescription() != null) {
                        obj.set("description", om.valueToTree(this.getDescription()));
                    }
                    if (this.getLayerName() != null) {
                        obj.set("layerName", om.valueToTree(this.getLayerName()));
                    }
                    if (this.getLicenseInfo() != null) {
                        obj.set("licenseInfo", om.valueToTree(this.getLicenseInfo()));
                    }
                    if (this.getRetentionPolicy() != null) {
                        obj.set("retentionPolicy", om.valueToTree(this.getRetentionPolicy()));
                    }
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.sam.CfnLayerVersionProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * `AWS::Serverless::LayerVersion.CompatibleRuntimes`.
         * 
         * @see https://github.com/awslabs/serverless-application-model/blob/master/versions/2016-10-31.md#awsserverlesslayerversion
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.util.List<java.lang.String> getCompatibleRuntimes() {
            return this.jsiiGet("compatibleRuntimes", java.util.List.class);
        }

        /**
         * `AWS::Serverless::LayerVersion.ContentUri`.
         * 
         * @see https://github.com/awslabs/serverless-application-model/blob/master/versions/2016-10-31.md#awsserverlesslayerversion
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.lang.String getContentUri() {
            return this.jsiiGet("contentUri", java.lang.String.class);
        }

        /**
         * `AWS::Serverless::LayerVersion.Description`.
         * 
         * @see https://github.com/awslabs/serverless-application-model/blob/master/versions/2016-10-31.md#awsserverlesslayerversion
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.lang.String getDescription() {
            return this.jsiiGet("description", java.lang.String.class);
        }

        /**
         * `AWS::Serverless::LayerVersion.LayerName`.
         * 
         * @see https://github.com/awslabs/serverless-application-model/blob/master/versions/2016-10-31.md#awsserverlesslayerversion
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.lang.String getLayerName() {
            return this.jsiiGet("layerName", java.lang.String.class);
        }

        /**
         * `AWS::Serverless::LayerVersion.LicenseInfo`.
         * 
         * @see https://github.com/awslabs/serverless-application-model/blob/master/versions/2016-10-31.md#awsserverlesslayerversion
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.lang.String getLicenseInfo() {
            return this.jsiiGet("licenseInfo", java.lang.String.class);
        }

        /**
         * `AWS::Serverless::LayerVersion.RetentionPolicy`.
         * 
         * @see https://github.com/awslabs/serverless-application-model/blob/master/versions/2016-10-31.md#awsserverlesslayerversion
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.lang.String getRetentionPolicy() {
            return this.jsiiGet("retentionPolicy", java.lang.String.class);
        }
    }
}
